@@ -4,7 +4,9 @@
 #include "private/qjni_p.h"
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QAndroidJniEnvironment>
+#endif
 
 using namespace QKeychain;
 
@@ -113,7 +115,7 @@ bool KeyStore::containsAlias(const QString &alias) const
 
 bool KeyStore::deleteEntry(const QString &alias) const
 {
-    callMethod<void>("deleteEntry", "(Ljava/lang/String;)Z", fromString(alias).object());
+    callMethod<void>("deleteEntry", "(Ljava/lang/String;)V", fromString(alias).object());
     return handleExceptions();
 }
 
